package com.example.gatewayissue

import io.restassured.RestAssured.given
import io.restassured.http.ContentType
import org.junit.jupiter.api.Assertions
import org.junit.jupiter.api.DisplayName
import org.junit.jupiter.api.Test
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.boot.test.web.server.LocalServerPort

@SpringBootTest(
    webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT
)
class GatewayissueApplicationTests {

    @LocalServerPort
    var port: Int = 0

    @Test
    @DisplayName(
        "Request doesn't respect URL in the route"
    )
    fun passthroughNoUrl() {
        val body = """{"key": "value"}"""

        val response = given()
            .body(body)
            .port(port)
            .`when`()
            .contentType(ContentType.JSON)
            .post("/other/transcoder/v1/break")
            .then()
            .assertThat()
            .statusCode(200)
            .extract()
            .asString()

        Assertions.assertEquals(body, response)
    }

    @Test
    @DisplayName(
        "Direct call to the endpoint works fine"
    )
    fun directCall() {
        val body = """{"key": "value"}"""

        val response = given()
            .body(body)
            .port(port)
            .`when`()
            .contentType(ContentType.JSON)
            .post("/base/transcoder/v1/break")
            .then()
            .assertThat()
            .statusCode(200)
            .extract()
            .asString()

        Assertions.assertEquals(body, response)
    }

}
